sqlobject.tests.test_subqueries module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_subqueries module

class `sqlobject.tests.test_subqueries.` `SOTestIn1`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `col1`
  `j` = so_test_in1
  `q` = so_test_in1
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_subqueries.SOTestIn1`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_in1'

class `sqlobject.tests.test_subqueries.` `SOTestIn2`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `col2`
  `j` = so_test_in2
  `q` = so_test_in2
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_subqueries.SOTestIn2`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_in2'

class `sqlobject.tests.test_subqueries.` `SOTestOuter`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `fk`
  property `fkID`
  `j` = so_test_outer
  `q` = so_test_outer
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_subqueries.SOTestOuter`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_outer'

`sqlobject.tests.test_subqueries.` `insert`()

`sqlobject.tests.test_subqueries.` `setup`()

`sqlobject.tests.test_subqueries.` `test_1syntax_in`()

`sqlobject.tests.test_subqueries.` `test_2perform_in`()

`sqlobject.tests.test_subqueries.` `test_3syntax_exists`()

`sqlobject.tests.test_subqueries.` `test_4perform_direct`()

`sqlobject.tests.test_subqueries.` `test_4perform_exists`()

`sqlobject.tests.test_subqueries.` `test_4syntax_direct`()

`sqlobject.tests.test_subqueries.` `test_5perform_direct`()

`sqlobject.tests.test_subqueries.` `test_6perform_join`()

`sqlobject.tests.test_subqueries.` `test_6syntax_join`()